==> hs-OpenGL-2.2.3.1_2%2C1.tbz: lib/ghc-7.4.1/cabal/OpenGL-2.2.3.1/register.sh <==
#!/bin/sh
echo 'name: OpenGL
version: 2.2.3.1
id: OpenGL-2.2.3.1-2a936b81523ccff850cd4a045dfe7af2

license: BSD3
copyright:
maintainer: Sven Panne <sven.panne@aedion.de>
stability:
homepage: http://www.haskell.org/HOpenGL/
package-url:
synopsis: A binding for the OpenGL graphics system
description: A Haskell binding for the OpenGL graphics system (GL, version
             2.1) and its accompanying utility library (GLU, version 1.3).
             OpenGL is the industry'\''s most widely used and supported 2D and 3D
             graphics application programming interface (API), incorporating
             a broad set of rendering, texture mapping, special effects, and
             other powerful visualization functions.  For more information
             about OpenGL, please see: <http://www.opengl.org/>.
category: Graphics
author:
exposed: True
exposed-modules: Graphics.Rendering.OpenGL.GL.Antialiasing
                 Graphics.Rendering.OpenGL.GL.BasicTypes
                 Graphics.Rendering.OpenGL.GL.BeginEnd
                 Graphics.Rendering.OpenGL.GL.Bitmaps
                 Graphics.Rendering.OpenGL.GL.BufferObjects
                 Graphics.Rendering.OpenGL.GL.Clipping
                 Graphics.Rendering.OpenGL.GL.Colors
                 Graphics.Rendering.OpenGL.GL.ColorSum
                 Graphics.Rendering.OpenGL.GL.CoordTrans
                 Graphics.Rendering.OpenGL.GL.DisplayLists
                 Graphics.Rendering.OpenGL.GL.Evaluators
                 Graphics.Rendering.OpenGL.GL.Feedback
                 Graphics.Rendering.OpenGL.GL.FlushFinish
                 Graphics.Rendering.OpenGL.GL.Fog
                 Graphics.Rendering.OpenGL.GL.Framebuffer
                 Graphics.Rendering.OpenGL.GL.Hints Graphics.Rendering.OpenGL.GL
                 Graphics.Rendering.OpenGL.GL.LineSegments
                 Graphics.Rendering.OpenGL.GL.PerFragment
                 Graphics.Rendering.OpenGL.GL.PixelRectangles.ColorTable
                 Graphics.Rendering.OpenGL.GL.PixelRectangles.Convolution
                 Graphics.Rendering.OpenGL.GL.PixelRectangles.Histogram
                 Graphics.Rendering.OpenGL.GL.PixelRectangles
                 Graphics.Rendering.OpenGL.GL.PixelRectangles.Minmax
                 Graphics.Rendering.OpenGL.GL.PixelRectangles.PixelMap
                 Graphics.Rendering.OpenGL.GL.PixelRectangles.PixelStorage
                 Graphics.Rendering.OpenGL.GL.PixelRectangles.PixelTransfer
                 Graphics.Rendering.OpenGL.GL.PixelRectangles.Rasterization
                 Graphics.Rendering.OpenGL.GL.Points
                 Graphics.Rendering.OpenGL.GL.Polygons
                 Graphics.Rendering.OpenGL.GL.RasterPos
                 Graphics.Rendering.OpenGL.GL.ReadCopyPixels
                 Graphics.Rendering.OpenGL.GL.Rectangles
                 Graphics.Rendering.OpenGL.GL.SavingState
                 Graphics.Rendering.OpenGL.GL.Selection
                 Graphics.Rendering.OpenGL.GL.Shaders
                 Graphics.Rendering.OpenGL.GL.StateVar
                 Graphics.Rendering.OpenGL.GL.StringQueries
                 Graphics.Rendering.OpenGL.GL.Texturing.Application
                 Graphics.Rendering.OpenGL.GL.Texturing.Environments
                 Graphics.Rendering.OpenGL.GL.Texturing
                 Graphics.Rendering.OpenGL.GL.Texturing.Objects
                 Graphics.Rendering.OpenGL.GL.Texturing.Parameters
                 Graphics.Rendering.OpenGL.GL.Texturing.Queries
                 Graphics.Rendering.OpenGL.GL.Texturing.Specification
                 Graphics.Rendering.OpenGL.GLU.Errors Graphics.Rendering.OpenGL.GLU
                 Graphics.Rendering.OpenGL.GLU.Initialization
                 Graphics.Rendering.OpenGL.GLU.Matrix
                 Graphics.Rendering.OpenGL.GLU.Mipmapping
                 Graphics.Rendering.OpenGL.GLU.NURBS
                 Graphics.Rendering.OpenGL.GLU.Quadrics
                 Graphics.Rendering.OpenGL.GLU.Tessellation
                 Graphics.Rendering.OpenGL.GL.VertexArrays
                 Graphics.Rendering.OpenGL.GL.VertexSpec Graphics.Rendering.OpenGL
hidden-modules: Graphics.Rendering.OpenGL.GL.BlendingFactor
                Graphics.Rendering.OpenGL.GL.BufferMode
                Graphics.Rendering.OpenGL.GL.Capability
                Graphics.Rendering.OpenGL.GL.ComparisonFunction
                Graphics.Rendering.OpenGL.GL.ControlPoint
                Graphics.Rendering.OpenGL.GL.DataType
                Graphics.Rendering.OpenGL.GL.Domain
                Graphics.Rendering.OpenGL.GL.EdgeFlag
                Graphics.Rendering.OpenGL.GL.Exception
                Graphics.Rendering.OpenGL.GL.Extensions
                Graphics.Rendering.OpenGL.GL.Face
                Graphics.Rendering.OpenGL.GL.GLboolean
                Graphics.Rendering.OpenGL.GL.IOState
                Graphics.Rendering.OpenGL.GL.PeekPoke
                Graphics.Rendering.OpenGL.GL.PixelData
                Graphics.Rendering.OpenGL.GL.PixelFormat
                Graphics.Rendering.OpenGL.GL.PixelRectangles.Reset
                Graphics.Rendering.OpenGL.GL.PixelRectangles.Sink
                Graphics.Rendering.OpenGL.GL.PointParameter
                Graphics.Rendering.OpenGL.GL.PolygonMode
                Graphics.Rendering.OpenGL.GL.PrimitiveMode
                Graphics.Rendering.OpenGL.GL.QueryUtils
                Graphics.Rendering.OpenGL.GL.RenderMode
                Graphics.Rendering.OpenGL.GL.Tensor
                Graphics.Rendering.OpenGL.GL.Texturing.PixelInternalFormat
                Graphics.Rendering.OpenGL.GL.Texturing.TexParameter
                Graphics.Rendering.OpenGL.GL.Texturing.TextureTarget
                Graphics.Rendering.OpenGL.GL.Texturing.TextureUnit
                Graphics.Rendering.OpenGL.GL.VertexAttributes
                Graphics.Rendering.OpenGL.GLU.ErrorsInternal
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/OpenGL-2.2.3.1
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/OpenGL-2.2.3.1
              /usr/local/lib
hs-libraries: HSOpenGL-2.2.3.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
              /usr/local/lib/ghc-7.4.1/cabal/OpenGL-2.2.3.1/include
includes: HsOpenGL.h
depends: base-4.5.0.0-1a022b3476300ed3e5bfdd46dd7221d0
hugs-options:
cc-options:
ld-options: -L/usr/local/lib -lGLU -lGL -lm
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/OpenGL-2.2.3.1/html/OpenGL.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/OpenGL-2.2.3.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-OpenGL-2.2.3.1_4%2C1.tbz: lib/ghc-7.4.2/cabal/OpenGL-2.2.3.1/register.sh <==
#!/bin/sh
echo 'name: OpenGL
version: 2.2.3.1
id: OpenGL-2.2.3.1-b7722e0f0e194395d4420297e79a1edf

license: BSD3
copyright:
maintainer: Sven Panne <sven.panne@aedion.de>
stability:
homepage: http://www.haskell.org/HOpenGL/
package-url:
synopsis: A binding for the OpenGL graphics system
description: A Haskell binding for the OpenGL graphics system (GL, version
             2.1) and its accompanying utility library (GLU, version 1.3).
             OpenGL is the industry'\''s most widely used and supported 2D and 3D
             graphics application programming interface (API), incorporating
             a broad set of rendering, texture mapping, special effects, and
             other powerful visualization functions.  For more information
             about OpenGL, please see: <http://www.opengl.org/>.
category: Graphics
author:
exposed: True
exposed-modules: Graphics.Rendering.OpenGL.GL.Antialiasing
                 Graphics.Rendering.OpenGL.GL.BasicTypes
                 Graphics.Rendering.OpenGL.GL.BeginEnd
                 Graphics.Rendering.OpenGL.GL.Bitmaps
                 Graphics.Rendering.OpenGL.GL.BufferObjects
                 Graphics.Rendering.OpenGL.GL.Clipping
                 Graphics.Rendering.OpenGL.GL.Colors
                 Graphics.Rendering.OpenGL.GL.ColorSum
                 Graphics.Rendering.OpenGL.GL.CoordTrans
                 Graphics.Rendering.OpenGL.GL.DisplayLists
                 Graphics.Rendering.OpenGL.GL.Evaluators
                 Graphics.Rendering.OpenGL.GL.Feedback
                 Graphics.Rendering.OpenGL.GL.FlushFinish
                 Graphics.Rendering.OpenGL.GL.Fog
                 Graphics.Rendering.OpenGL.GL.Framebuffer
                 Graphics.Rendering.OpenGL.GL.Hints Graphics.Rendering.OpenGL.GL
                 Graphics.Rendering.OpenGL.GL.LineSegments
                 Graphics.Rendering.OpenGL.GL.PerFragment
                 Graphics.Rendering.OpenGL.GL.PixelRectangles.ColorTable
                 Graphics.Rendering.OpenGL.GL.PixelRectangles.Convolution
                 Graphics.Rendering.OpenGL.GL.PixelRectangles.Histogram
                 Graphics.Rendering.OpenGL.GL.PixelRectangles
                 Graphics.Rendering.OpenGL.GL.PixelRectangles.Minmax
                 Graphics.Rendering.OpenGL.GL.PixelRectangles.PixelMap
                 Graphics.Rendering.OpenGL.GL.PixelRectangles.PixelStorage
                 Graphics.Rendering.OpenGL.GL.PixelRectangles.PixelTransfer
                 Graphics.Rendering.OpenGL.GL.PixelRectangles.Rasterization
                 Graphics.Rendering.OpenGL.GL.Points
                 Graphics.Rendering.OpenGL.GL.Polygons
                 Graphics.Rendering.OpenGL.GL.RasterPos
                 Graphics.Rendering.OpenGL.GL.ReadCopyPixels
                 Graphics.Rendering.OpenGL.GL.Rectangles
                 Graphics.Rendering.OpenGL.GL.SavingState
                 Graphics.Rendering.OpenGL.GL.Selection
                 Graphics.Rendering.OpenGL.GL.Shaders
                 Graphics.Rendering.OpenGL.GL.StateVar
                 Graphics.Rendering.OpenGL.GL.StringQueries
                 Graphics.Rendering.OpenGL.GL.Texturing.Application
                 Graphics.Rendering.OpenGL.GL.Texturing.Environments
                 Graphics.Rendering.OpenGL.GL.Texturing
                 Graphics.Rendering.OpenGL.GL.Texturing.Objects
                 Graphics.Rendering.OpenGL.GL.Texturing.Parameters
                 Graphics.Rendering.OpenGL.GL.Texturing.Queries
                 Graphics.Rendering.OpenGL.GL.Texturing.Specification
                 Graphics.Rendering.OpenGL.GLU.Errors Graphics.Rendering.OpenGL.GLU
                 Graphics.Rendering.OpenGL.GLU.Initialization
                 Graphics.Rendering.OpenGL.GLU.Matrix
                 Graphics.Rendering.OpenGL.GLU.Mipmapping
                 Graphics.Rendering.OpenGL.GLU.NURBS
                 Graphics.Rendering.OpenGL.GLU.Quadrics
                 Graphics.Rendering.OpenGL.GLU.Tessellation
                 Graphics.Rendering.OpenGL.GL.VertexArrays
                 Graphics.Rendering.OpenGL.GL.VertexSpec Graphics.Rendering.OpenGL
hidden-modules: Graphics.Rendering.OpenGL.GL.BlendingFactor
                Graphics.Rendering.OpenGL.GL.BufferMode
                Graphics.Rendering.OpenGL.GL.Capability
                Graphics.Rendering.OpenGL.GL.ComparisonFunction
                Graphics.Rendering.OpenGL.GL.ControlPoint
                Graphics.Rendering.OpenGL.GL.DataType
                Graphics.Rendering.OpenGL.GL.Domain
                Graphics.Rendering.OpenGL.GL.EdgeFlag
                Graphics.Rendering.OpenGL.GL.Exception
                Graphics.Rendering.OpenGL.GL.Extensions
                Graphics.Rendering.OpenGL.GL.Face
                Graphics.Rendering.OpenGL.GL.GLboolean
                Graphics.Rendering.OpenGL.GL.IOState
                Graphics.Rendering.OpenGL.GL.PeekPoke
                Graphics.Rendering.OpenGL.GL.PixelData
                Graphics.Rendering.OpenGL.GL.PixelFormat
                Graphics.Rendering.OpenGL.GL.PixelRectangles.Reset
                Graphics.Rendering.OpenGL.GL.PixelRectangles.Sink
                Graphics.Rendering.OpenGL.GL.PointParameter
                Graphics.Rendering.OpenGL.GL.PolygonMode
                Graphics.Rendering.OpenGL.GL.PrimitiveMode
                Graphics.Rendering.OpenGL.GL.QueryUtils
                Graphics.Rendering.OpenGL.GL.RenderMode
                Graphics.Rendering.OpenGL.GL.Tensor
                Graphics.Rendering.OpenGL.GL.Texturing.PixelInternalFormat
                Graphics.Rendering.OpenGL.GL.Texturing.TexParameter
                Graphics.Rendering.OpenGL.GL.Texturing.TextureTarget
                Graphics.Rendering.OpenGL.GL.Texturing.TextureUnit
                Graphics.Rendering.OpenGL.GL.VertexAttributes
                Graphics.Rendering.OpenGL.GLU.ErrorsInternal
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/OpenGL-2.2.3.1
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/OpenGL-2.2.3.1
              /usr/local/lib
hs-libraries: HSOpenGL-2.2.3.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
              /usr/local/lib/ghc-7.4.2/cabal/OpenGL-2.2.3.1/include
includes: HsOpenGL.h
depends: base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
hugs-options:
cc-options:
ld-options: -L/usr/local/lib "-Wl,-rpath=/usr/local/lib/gcc46"
            -lGLU -lGL -lm
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/OpenGL-2.2.3.1/html/OpenGL.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/OpenGL-2.2.3.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
